ERMLPInteraction
================

.. currentmodule:: pykeen.nn.modules

.. autoclass:: ERMLPInteraction
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~ERMLPInteraction.func
      ~ERMLPInteraction.reset_parameters

   .. rubric:: Methods Documentation

   .. automethod:: func
   .. automethod:: reset_parameters
